@@ -102,13 +102,17 @@ def convert_labels(labels_str):
 @click.option('--files', help='comma separated list of file paths to add')
 @click.option('--opts', help='comma separated list of key=val pairs')
 @click.option('--update', is_flag=True, help='update opts instead of replace')
-def pack_from_s3(module, clz, name, bucket, path, labels=None, files=None, opts=None, update=False):
+@click.option('--no_ssl', is_flag=True, help='do not use SSL')
+@click.option('--no_verify_ssl', is_flag=True, help='do not verify SSL')
+def pack_from_s3(module, clz, name, bucket, path, labels=None, files=None, opts=None, update=False, no_ssl=False, no_verify_ssl=False):
     s3 = boto3.resource('s3',
         endpoint_url=os.environ['S3_ENDPOINT_URL'],
         aws_access_key_id=os.environ['AWS_ACCESS_KEY_ID'],
         aws_secret_access_key=os.environ['AWS_SECRET_ACCESS_KEY'],
         config=Config(signature_version='s3v4'),
-        region_name='us-east-1'
+        region_name='us-east-1',
+        use_ssl=(not no_ssl),
+        verify=(False if no_verify_ssl else None),
     )
 
     def download_directory(bucket_name, directory, local_directory=None):
@@ -185,8 +189,10 @@ def get_pod_name(bento):
 @click.option('--bento', help="bento name in 'name:version' format")
 @click.option('--path', help="path to saved artifacts")
 @click.option('--registry', help="private registry in 'host:port' format")
+@click.option('--s3_endpoint', help="S3 endpoint URL")
+@click.option('--insecure', is_flag=True, help='do not use SSL')
 @click.option('--uid', help="unique ID")
-def get_kaniko_manifest(bento, path, registry, uid=None, silent=False):
+def get_kaniko_manifest(bento, path, registry, s3_endpoint, insecure=False, uid=None, silent=False):
     if ':' in bento:
         name, version = bento.split(':')
     else:
@@ -198,7 +204,7 @@ def get_kaniko_manifest(bento, path, registry, uid=None, silent=False):
 
     image_name = camel_to_kebab(name)
     pod_name = '{}-{}'.format(image_name, uid)
-    manifest = gen_kaniko_manifest(name, pod_name, image_name, version, path, registry)
+    manifest = gen_kaniko_manifest(name, pod_name, image_name, version, path, registry=registry, s3_endpoint=s3_endpoint, insecure=insecure)
     if not silent: click.echo(manifest)
     return manifest, pod_name
 
@@ -278,10 +284,12 @@ def first_bento_with_label(labels):
 @click.command()
 @click.option('--bento', help="bento name in 'name:version' format")
 @click.option('--registry', help="private registry in 'host:port' format")
+@click.option('--s3_endpoint', help="S3 endpoint URL")
+@click.option('--insecure', is_flag=True, help='do not use SSL')
 @click.pass_context
-def containerize(ctx, bento, registry):
+def containerize(ctx, bento, registry, s3_endpoint, insecure=False):
     path = ctx.invoke(get_saved_path, bento=bento, silent=True)
-    manifest, pod_name = ctx.invoke(get_kaniko_manifest, bento=bento, path=path, registry=registry, silent=True)
+    manifest, pod_name = ctx.invoke(get_kaniko_manifest, bento=bento, path=path, registry=registry, s3_endpoint=s3_endpoint, insecure=insecure, silent=True)
     from_yaml(manifest)
     click.echo(pod_name)
     return pod_name
